package videorental;

import java.util.ArrayList;
import java.util.Formatter;
import java.util.List;

/**
 * A class representing a customer in the application.
 *
 * @author Martin Fowler
 * @author Zachary Palmer
 */
public class Customer {
    private String name;
    private List<Rental> rentals = new ArrayList<>();

    public Customer(String name) {
        this.name = name;
    }

    public String getName() {
        return name;
    }

    public void addRental(Rental rental) {
        this.rentals.add(rental);
    }

    public String generateStatement() {
        Formatter formatter = new Formatter();
        formatter.format("Rental Record for %s\n", getName());

        double totalAmount = calculateTotalRentalAmount();
        int frequentRenterPoints = calculateFrequentRenterPoints();
        formatRentalStatements(formatter);

        // add footer lines
        formatter.format("Amount spent is $%5.2f\n", totalAmount);
        formatter.format("You earned %d frequent renter points", frequentRenterPoints);

        String result = formatter.out().toString();
        formatter.close();
        return result;
    }

    private void formatRentalStatements(Formatter formatter) {
        for (Rental rental : this.rentals) {
            // show figures for this rental
            rental.formatAsText(formatter);
        }
    }

    private int calculateFrequentRenterPoints() {
        int frequentRenterPoints = 0;
        for (Rental rental : this.rentals) {
            frequentRenterPoints = rental.calculateFrequentRenterPoints(frequentRenterPoints);
        }
        return frequentRenterPoints;
    }

    private double calculateTotalRentalAmount() {
        double totalAmount = 0;
        for (Rental rental : this.rentals) {
            totalAmount += rental.calculateRentalCost();
        }
        return totalAmount;
    }

}
