package videorental;

import java.util.Formatter;

/**
 * Represents the rental of a single movie.
 *
 * @author Martin Fowler
 * @author Zachary Palmer
 */
public class Rental {
    private Movie movie;
    private int daysRented;
    private int daysLeft;

    public Rental(Movie movie, int daysRented) {
        super();
        this.movie = movie;
        this.daysRented = daysRented;
        this.daysLeft = daysRented;
    }

    public Movie getMovie() {
        return movie;
    }

    public int getDaysRented() {
        return daysRented;
    }

    public int getDaysLeft() {
        return daysLeft;
    }

    public void setDaysLeft(int daysLeft) {
        this.daysLeft = daysLeft;
    }

    public double calculateRentalCost() {
        return this.movie.calculateRentalCost(this.daysRented);
    }

    public void formatAsText(Formatter formatter) {
        formatter.format("\t%s\t(%d/%d)\t$%5.2f\n",
                getMovie().getTitle(), getDaysLeft(), getDaysRented(), calculateRentalCost());
    }

    public int calculateFrequentRenterPoints(int frequentRenterPoints) {
        return this.movie.calculateFrequentRenterPoints(this.daysRented, frequentRenterPoints);
    }
}
